@@ -12,7 +12,7 @@ def cycleUpdateHotList(configFileName, isTest):
 	subjectHistory, worksHistory, historyTime, endTime = getNewestHistory()
 	oriWorksDict = {}
 	while True:
-		try:
+		#try:
 			start = time.time()
 			ilog.info('start:' + str(start) + '(' + time.strftime(es.esTimeFormatNoMs, time.localtime(start)) + ')')
 			
@@ -24,7 +24,7 @@ def cycleUpdateHotList(configFileName, isTest):
 				subjectHistory, worksHistory, historyTime, endTime = getNewestHistory()
 				oriWorksDict = {}
 
-			oriWorksDict = getNewestWorksList(oriWorksDict)
+			oriWorksDict = getNewestWorksList(oriWorksDict, worksHistory)
 			
 			endTime = onceUpdateHotList(subjectHistory, worksHistory, oriWorksDict, endTime, configFileName, isTest)
 
@@ -34,20 +34,26 @@ def cycleUpdateHotList(configFileName, isTest):
 			maxInterval = 150 if isTest else 600
 			if cost < maxInterval:
 				time.sleep(maxInterval - cost)
-		except Exception as error:
-			ilog.info('Error: (' + time.strftime(es.esTimeFormatNoMs, time.localtime(time.time())) + ')' + str(error))
-			time.sleep(600)
+		#except Exception as error:
+		#	ilog.info('Error: (' + time.strftime(es.esTimeFormatNoMs, time.localtime(time.time())) + ')' + str(error))
+		#	time.sleep(600)
 
 def getNewestHistory():
 	worksHistory = dataDispose.getWorksHistory()
-	historyTime = worksHistory.values()[0]['time']
-	return dataDispose.getSubjectHistory(), worksHistory, historyTime, historyTime
+	historyTime = 0 if len(worksHistory) == 0 else worksHistory.values()[0]['time']
+	#return dataDispose.getSubjectHistory(), worksHistory, historyTime, historyTime
+	return {}, worksHistory, historyTime, historyTime
 
-def getNewestWorksList(oldOriWorksDict):
+def getNewestWorksList(oldOriWorksDict, worksHistory):
 	oriWorksDict = {}
 	for works in dataDispose.getWorksList():
 		vid = works.vid
-		oriWorksDict[vid] = oldOriWorksDict[vid] if oldOriWorksDict.has_key(vid) else works
+		if oldOriWorksDict.has_key(vid):
+			oriWorksDict[vid] = oldOriWorksDict[vid]
+		else:
+			oriWorksDict[vid] = works
+			if worksHistory.has_key(vid):
+				works.updateHistory(worksHistory[vid])
 	return oriWorksDict
 
 def onceUpdateHotList(subjectHistory, worksHistory, oriWorksDict, startTime, configFileName, isTest):
@@ -72,7 +78,7 @@ def updateHotList(subjectHistory, worksHistory, oriWorksDict, startTime, config)
 			worksDict[vid] = oriWorksDict[vid]
 
 	endTime = int(time.time())
-	newHits = es.searchStatisticsDataByBody("works_actions", {"query": {"bool": {"must": [{"range": {"createTime": {"gte": startTime, "lt": endTime}}}, {"terms": {"action": [1, 2, 12, 13, 14, 15, 16, 17]}}]}}, "size": 10000})
+	newHits = es.searchStatisticsDataByBody("works_actions", {"query": {"bool": {"must": [{"range": {"createTime": {"gte": startTime, "lt": endTime}}}, {"terms": {"action": [1, 2, 3, 5, 12, 13, 14, 15, 16, 17]}}]}}, "size": 10000})
 	for hit in newHits:
 		action = hit['_source']
 		vid = action['vid']
@@ -83,15 +89,16 @@ def updateHotList(subjectHistory, worksHistory, oriWorksDict, startTime, config)
 
 	updateWeight(config['weight'])
 	
-	dauFactor = dataDispose.getDauFactor()
-	ilog.info('dauFactor:' + str(dauFactor))
-	worksHots = calHotV2(subjectHistory, worksHistory, worksDict.values(), dauFactor, dbConfig['aidWeights'], dbConfig['vidWeights'])
+	#dauFactor = dataDispose.getDauFactor()
+	#ilog.info('dauFactor:' + str(dauFactor))
+	worksHots = calHotV2(subjectHistory, worksHistory, worksDict.values(), 0, dbConfig['aidWeights'], dbConfig['vidWeights'])
 
 	ilog.info('got hot list:' + str(time.time() - start))
 
-	ilog.info('update works hot: ' + ('success ' if es.coverStatisticsData('works_hot', worksHots) else 'fail ') + str(time.time() - start))
+	#ilog.info('update works hot: ' + ('success ' if es.coverStatisticsData('works_hot', worksHots) else 'fail ') + str(time.time() - start))
+	ilog.info('update works hot: ' + ('success ' if es.updateStatisticsData('works_hot_simulation', worksHots) else 'fail ') + str(time.time() - start))
 	
-	ilog.info('update redis works hot: ' + ('success ' if es.updateRedisWorksHots(getRedisWorksHots(worksHots)) else 'fail ') + str(time.time() - start))
+	#ilog.info('update redis works hot: ' + ('success ' if es.updateRedisWorksHots(getRedisWorksHots(worksHots)) else 'fail ') + str(time.time() - start))
 
 	return endTime
 
