@@ -52,6 +52,14 @@ TimeDecay = {
 
 SameAidDecay = 0.0
 
+Weight = {
+	"conv": 0.4,
+	"like": 0.1,
+	"share": 0.1,
+	"longPlay": 0.2,
+	"sub": 0.2
+}
+
 def calSubjectScore(subjectList):
 	subjectArgs = []
 	for subject in subjectList:
@@ -66,55 +74,60 @@ def calWorksScore(worksList, dauFactor=10):
 		return
 
 	worksArgs = []
-	worksDurationTimeAvg = {}
-	worksDurationPlay = {}
 	for works in worksList:
-		worksArgs.append([works.play, works.like, works.shareF, works.shareI, works.replay, works.longPlay, works.sub])
-		if worksDurationTimeAvg.has_key(works.durationIndex):
-			worksDurationTimeAvg[works.durationIndex] += works.timeAvg
-			worksDurationPlay[works.durationIndex] += works.play
-		else:
-			worksDurationTimeAvg[works.durationIndex] = works.timeAvg
-			worksDurationPlay[works.durationIndex] = works.play
+		conv = 0 if works.resShow < 200 else works.resShowPlay * 1.0 / works.resShow
+		likeRatio = 0 if works.play < 20 else works.like * 1.0 / works.play
+		shareRatio = 0 if works.play < 20 else works.share * 1.0 / works.play
+		longPlayRatio = 0 if works.play < 20 else works.longPlay * 1.0 / works.play
+		subRatio = 0 if works.play < 20 else works.sub * 1.0 / works.play
+		worksArgs.append([conv, likeRatio, shareRatio, longPlayRatio, subRatio])
 	worksMat = imatrix.inOne(mat(worksArgs))
-	worksMatTwo = imatrix.inOneDiv(hstack((worksMat[:, 0] * WorksWeight['play'] + worksMat[:, 1] * WorksWeight['like'] + worksMat[:, 2] * WorksWeight['shareF'] + worksMat[:, 3] * WorksWeight['shareI'] + worksMat[:, 4] * WorksWeight['replay'], worksMat[:, 5] * WorksWeight['longTime'] + worksMat[:, 6] * WorksWeight['subAdd'])))
-	worksMatFinal = imatrix.inOneDiv(worksMatTwo[:, 0] * (11 - dauFactor) + worksMatTwo[:, 1] * dauFactor)
+	worksMatFinal = worksMat[:, 0] * Weight['conv'] + worksMat[:, 1] * Weight['like'] + worksMat[:, 2] * Weight['share'] + worksMat[:, 3] * Weight['longPlay'] + worksMat[:, 4] * Weight['sub']
 
 	for index, works in enumerate(worksList):
 		works.score = worksMatFinal[index, 0]
-		works.ratio = worksDurationPlay[works.durationIndex]
 
 def updateWeight(weight):
-	global SubjectTotalWeight, SubjectWeight, WorksWeight, TimeDecay, SameAidDecay
-	SubjectTotalWeight = weight['subjectTotal']
-	SubjectWeight = weight['subject']
-	WorksWeight = weight['works']
-	TimeDecay = weight['timeDecay']
-	SameAidDecay = weight['sameAidDecay'] if weight.has_key('sameAidDecay') else 0.0	
+	global Weight
+	Weight = weight
 
 def calHotV2(subjectHistory, worksHistory, worksList, dauFactor, aidWeights, vidWeights):
 	calWorksScore(worksList, 11 - dauFactor)
 
+	'''
 	baseHot = []
 	for works in worksList:
 		vid = works.vid
 		aid = works.aid
-		baseHot.append([subjectHistory[aid]['score'] * worksHistory[vid]['ratio'] if subjectHistory.has_key(aid) and worksHistory.has_key(vid) else 0])
+		score = subjectHistory[aid]['score'] if subjectHistory.has_key(aid) else 0
+		ratio = worksHistory[vid]['ratio'] if worksHistory.has_key(vid) else works.ratio
+		baseHot.append([score * ratio])
 
 	baseHotMat = imatrix.inOneDiv(mat(baseHot))
+	'''
 
 	hotList = {}
 	for index, works in enumerate(worksList):
 		vid = works.vid
-		aid = works.aid
-		actionHot = (works.score + (worksHistory[vid]['score'] if worksHistory.has_key(vid) else 0)) / 2
+		#aid = works.aid
+		actionHot = works.score * 0.9 + (worksHistory[vid]['score'] if worksHistory.has_key(vid) else 0) * 0.1
+		#actionHot = works.score
+		'''
+		totalHot = (baseHotMat[index, 0] * SubjectTotalWeight + actionHot) * 100000
 		if vidWeights.has_key(vid):
 			weight = float(vidWeights[vid])
 		elif aidWeights.has_key(int(aid)):
 			weight = float(aidWeights[int(aid)])
 		else:
 			weight = 1
-		hotList[vid] = {'vid': vid, 'aid': aid, 'title': works.title, 'hot': (baseHotMat[index, 0] * SubjectTotalWeight + actionHot) * getDecayRatio(works.publishTime) * weight * 100000, 'isNew': works.publishTime < 72}
+		'''
+		hotData = works.toSaveEsData()
+		#hotData['baseHot'] = baseHotMat[index, 0]
+		#hotData['totalHot'] = totalHot
+		#hotData['hot'] = totalHot * getDecayRatio(works.publishTime) * weight
+		hotData['hot'] = actionHot
+		hotData['isNew'] = works.publishTime < 72 and works.resShow < 200
+		hotList[vid] = hotData
 
 	hotListFinal = {}
 	for index, item in enumerate(sorted(hotList.items(), key=lambda x: x[1]['hot'], reverse=True)):
